---
test_data: TD_70_69_38_46
test_title: no data
---

This data contains nothing.

Why is this no data needed?

It serves as noop case in tests.

Note that "nothing" applies to certain `data_envelope` classes only.
For example,
`ServiceEnvelopeClass.class_service` is not included,
but `ReservedEnvelopeClass.class_function` will still be loaded.
TODO: Data like `ReservedEnvelopeClass.class_function` is simply loaded unconditionally.
      Do we need a case with absolutely no data? If yes, we need to load all data conditionally.
